@@ -11,6 +11,9 @@ const textbox_input = {
     if (opts.placeholder) {
       this.target.find(".input_text").attr("placeholder", opts.placeholder)
     }
+    if (opts.default) {
+      this.target.find(".input_text").val(opts.default)
+    }
   },
   submit: function() {
     text = this.target.find(".input_text").val();
@@ -33,11 +36,7 @@ const textbox_input = {
     this.target.find(".input_text_saliency").hide();
     this.target.find(".input_text").show();
   },
-  renderFeatured: function(data) {
-    return data;
-  },
-  loadFeatured: function(data) {
-    this.clear();
-    this.target.find(".input_text").val(data);
+  load_example: function(data) {
+    this.target.find(".input_text").val(data);    
   }
 }
